@@ -7,10 +7,7 @@
 #include <qprinter.h>
 #include <qpicture.h>
 #include <qpainter.h>
-#include <qfiledialog.h>
-#include <qimagewriter.h>
 #include <qprintdialog.h>
-#include <qfileinfo.h>
 #include <qwt_counter.h>
 #include <qwt_picker_machine.h>
 #include <qwt_plot_zoomer.h>
@@ -25,7 +22,7 @@
 class Zoomer: public QwtPlotZoomer
 {
 public:
-    Zoomer( int xAxis, int yAxis, QwtPlotCanvas *canvas ):
+    Zoomer( int xAxis, int yAxis, QWidget *canvas ):
         QwtPlotZoomer( xAxis, yAxis, canvas )
     {
         setTrackerMode( QwtPicker::AlwaysOff );
@@ -121,7 +118,8 @@ MainWindow::MainWindow( QWidget *parent ):
     layout->addSpacing( 10 );
 
     QwtCounter *cntDamp = new QwtCounter( hBox );
-    cntDamp->setRange( 0.0, 5.0, 0.01 );
+    cntDamp->setRange( 0.0, 5.0 );
+    cntDamp->setSingleStep( 0.01 );
     cntDamp->setValue( 0.0 );
 
     layout->addWidget( cntDamp, 0 );
@@ -168,7 +166,9 @@ void MainWindow::print()
 
         if ( printer.colorMode() == QPrinter::GrayScale )
         {
+            renderer.setDiscardFlag( QwtPlotRenderer::DiscardBackground );
             renderer.setDiscardFlag( QwtPlotRenderer::DiscardCanvasBackground );
+            renderer.setDiscardFlag( QwtPlotRenderer::DiscardCanvasFrame );
             renderer.setLayoutFlag( QwtPlotRenderer::FrameWithScales );
         }
 
@@ -180,53 +180,8 @@ void MainWindow::print()
 
 void MainWindow::exportDocument()
 {
-#ifndef QT_NO_PRINTER
-    QString fileName = "bode.pdf";
-#else
-    QString fileName = "bode.png";
-#endif
-
-#ifndef QT_NO_FILEDIALOG
-    const QList<QByteArray> imageFormats =
-        QImageWriter::supportedImageFormats();
-
-    QStringList filter;
-    filter += "PDF Documents (*.pdf)";
-#ifndef QWT_NO_SVG
-    filter += "SVG Documents (*.svg)";
-#endif
-    filter += "Postscript Documents (*.ps)";
-
-    if ( imageFormats.size() > 0 )
-    {
-        QString imageFilter( "Images (" );
-        for ( int i = 0; i < imageFormats.size(); i++ )
-        {
-            if ( i > 0 )
-                imageFilter += " ";
-            imageFilter += "*.";
-            imageFilter += imageFormats[i];
-        }
-        imageFilter += ")";
-
-        filter += imageFilter;
-    }
-
-    fileName = QFileDialog::getSaveFileName(
-        this, "Export File Name", fileName,
-        filter.join( ";;" ), NULL, QFileDialog::DontConfirmOverwrite );
-#endif
-
-    if ( !fileName.isEmpty() )
-    {
-        QwtPlotRenderer renderer;
-
-        // flags to make the document look like the widget
-        renderer.setDiscardFlag( QwtPlotRenderer::DiscardBackground, false );
-        renderer.setLayoutFlag( QwtPlotRenderer::KeepFrames, true );
-
-        renderer.renderDocument( d_plot, fileName, QSizeF( 300, 200 ), 85 );
-    }
+    QwtPlotRenderer renderer;
+    renderer.exportTo( d_plot, "bode.pdf" );
 }
 
 void MainWindow::enableZoomMode( bool on )
