@@ -6,6 +6,7 @@
 #include <qwt_plot_curve.h>
 #include <qwt_legend.h>
 #include <qwt_text.h>
+#include <qwt_plot_canvas.h>
 #include <qmath.h>
 #include "complexnumber.h"
 #include "plot.h"
@@ -40,7 +41,11 @@ Plot::Plot( QWidget *parent ):
 
     setTitle( "Frequency Response of a Second-Order System" );
 
-    setCanvasBackground( QColor( Qt::darkBlue ) );
+    QwtPlotCanvas *canvas = new QwtPlotCanvas();
+    canvas->setBorderRadius( 10 );
+
+    setCanvas( canvas );
+    setCanvasBackground( QColor( "MidnightBlue" ) );
 
     // legend
     QwtLegend *legend = new QwtLegend;
@@ -49,8 +54,8 @@ Plot::Plot( QWidget *parent ):
     // grid
     QwtPlotGrid *grid = new QwtPlotGrid;
     grid->enableXMin( true );
-    grid->setMajPen( QPen( Qt::white, 0, Qt::DotLine ) );
-    grid->setMinPen( QPen( Qt::gray, 0 , Qt::DotLine ) );
+    grid->setMajorPen( Qt::white, 0, Qt::DotLine );
+    grid->setMinorPen( Qt::gray, 0 , Qt::DotLine );
     grid->attach( this );
 
     // axes
@@ -60,20 +65,20 @@ Plot::Plot( QWidget *parent ):
     setAxisTitle( QwtPlot::yRight, "Phase [deg]" );
 
     setAxisMaxMajor( QwtPlot::xBottom, 6 );
-    setAxisMaxMinor( QwtPlot::xBottom, 10 );
-    setAxisScaleEngine( QwtPlot::xBottom, new QwtLog10ScaleEngine );
+    setAxisMaxMinor( QwtPlot::xBottom, 9 );
+    setAxisScaleEngine( QwtPlot::xBottom, new QwtLogScaleEngine );
 
     // curves
     d_curve1 = new QwtPlotCurve( "Amplitude" );
     d_curve1->setRenderHint( QwtPlotItem::RenderAntialiased );
-    d_curve1->setPen( QPen( Qt::yellow ) );
+    d_curve1->setPen( Qt::yellow );
     d_curve1->setLegendAttribute( QwtPlotCurve::LegendShowLine );
     d_curve1->setYAxis( QwtPlot::yLeft );
     d_curve1->attach( this );
 
     d_curve2 = new QwtPlotCurve( "Phase" );
     d_curve2->setRenderHint( QwtPlotItem::RenderAntialiased );
-    d_curve2->setPen( QPen( Qt::cyan ) );
+    d_curve2->setPen( Qt::cyan );
     d_curve2->setLegendAttribute( QwtPlotCurve::LegendShowLine );
     d_curve2->setYAxis( QwtPlot::yRight );
     d_curve2->attach( this );
@@ -83,15 +88,15 @@ Plot::Plot( QWidget *parent ):
     d_marker1->setValue( 0.0, 0.0 );
     d_marker1->setLineStyle( QwtPlotMarker::VLine );
     d_marker1->setLabelAlignment( Qt::AlignRight | Qt::AlignBottom );
-    d_marker1->setLinePen( QPen( Qt::green, 0, Qt::DashDotLine ) );
+    d_marker1->setLinePen( Qt::green, 0, Qt::DashDotLine );
     d_marker1->attach( this );
 
     d_marker2 = new QwtPlotMarker();
     d_marker2->setLineStyle( QwtPlotMarker::HLine );
     d_marker2->setLabelAlignment( Qt::AlignRight | Qt::AlignBottom );
-    d_marker2->setLinePen( QPen( QColor( 200, 150, 0 ), 0, Qt::DashDotLine ) );
+    d_marker2->setLinePen( QColor( 200, 150, 0 ), 0, Qt::DashDotLine );
     d_marker2->setSymbol( new QwtSymbol( QwtSymbol::Diamond,
-        QColor( Qt::yellow ), QColor( Qt::green ), QSize( 7, 7 ) ) );
+        QColor( Qt::yellow ), QColor( Qt::green ), QSize( 8, 8 ) ) );
     d_marker2->attach( this );
 
     setDamp( 0.0 );
