@@ -19,7 +19,7 @@ void CpuPieMarker::draw( QPainter *painter,
     const QwtScaleMap &, const QwtScaleMap &,
     const QRectF &rect ) const
 {
-    const CpuPlot *cpuPlot = ( CpuPlot * )plot();
+    const CpuPlot *cpuPlot = static_cast<CpuPlot *> ( plot() );
 
     const QwtScaleMap yMap = cpuPlot->canvasMap( QwtPlot::yLeft );
 
@@ -33,17 +33,17 @@ void CpuPieMarker::draw( QPainter *painter,
 
     const int dataType[] = { CpuPlot::User, CpuPlot::System, CpuPlot::Idle };
 
-    int angle = ( int )( 5760 * 0.75 );
+    int angle = static_cast<int>( 5760 * 0.75 );
     for ( unsigned int i = 0;
         i < sizeof( dataType ) / sizeof( dataType[0] ); i++ )
     {
         const QwtPlotCurve *curve = cpuPlot->cpuCurve( dataType[i] );
         if ( curve->dataSize() > 0 )
         {
-            const int value = ( int )( 5760 * curve->sample( 0 ).y() / 100.0 );
+            const int value = static_cast<int>( 5760 * curve->sample( 0 ).y() / 100.0 );
 
             painter->save();
-            painter->setBrush( QBrush( curve->pen().color(), Qt::SolidPattern ) );
+            painter->setBrush( QBrush( curve->brush().color(), Qt::SolidPattern ) );
             if ( value != 0 )
                 painter->drawPie( pieRect, -angle, -value );
             painter->restore();
@@ -52,4 +52,3 @@ void CpuPieMarker::draw( QPainter *painter,
         }
     }
 }
-
