@@ -18,8 +18,9 @@ public:
         QWidget( parent )
     {
         d_thermo = new QwtThermo( this );
-        d_thermo->setOrientation( Qt::Horizontal, QwtThermo::NoScale );
-        d_thermo->setRange( 0.0, 1.0 );
+        d_thermo->setOrientation( Qt::Horizontal );
+        d_thermo->setScalePosition( QwtThermo::NoScale );
+        d_thermo->setScale( 0.0, 1.0 );
         d_thermo->setFillBrush( Qt::green );
 
         QLabel *label = new QLabel( "Tuning", this );
@@ -45,18 +46,29 @@ private:
 TunerFrame::TunerFrame( QWidget *parent ):
     QFrame( parent )
 {
-    d_sliderFrequency = new QwtSlider( this, Qt::Horizontal, QwtSlider::TopScale );
-    d_sliderFrequency->setRange( 87.5, 108, 0.01, 10 );
+    const double freqMin = 87.5;
+    const double freqMax = 108;
+
+    d_sliderFrequency = new QwtSlider( this );
+    d_sliderFrequency->setOrientation( Qt::Horizontal );
+    d_sliderFrequency->setScalePosition( QwtSlider::TrailingScale );
+    d_sliderFrequency->setScale( freqMin, freqMax );
+    d_sliderFrequency->setTotalSteps( 
+        qRound( ( freqMax - freqMin ) / 0.01 ) );
+    d_sliderFrequency->setSingleSteps( 1 );
+    d_sliderFrequency->setPageSteps( 10 );
     d_sliderFrequency->setScaleMaxMinor( 5 );
     d_sliderFrequency->setScaleMaxMajor( 12 );
-    d_sliderFrequency->setHandleSize( 80, 20 );
+    d_sliderFrequency->setHandleSize( QSize( 80, 20 ) );
     d_sliderFrequency->setBorderWidth( 1 );
 
     d_thermoTune = new TuningThermo( this );
 
     d_wheelFrequency = new QwtWheel( this );
     d_wheelFrequency->setMass( 0.5 );
-    d_wheelFrequency->setRange( 87.5, 108, 0.01 );
+    d_wheelFrequency->setRange( 87.5, 108 );
+    d_wheelFrequency->setSingleStep( 0.01 );
+    d_wheelFrequency->setPageStepCount( 10 );
     d_wheelFrequency->setTotalAngle( 3600.0 );
     d_wheelFrequency->setFixedHeight( 30 );
 
