@@ -26,14 +26,16 @@ public:
     Qt::ScrollBarPolicy mode;
 };
 
-ScrollZoomer::ScrollZoomer( QwtPlotCanvas *canvas ):
+ScrollZoomer::ScrollZoomer( QWidget *canvas ):
     QwtPlotZoomer( canvas ),
     d_cornerWidget( NULL ),
     d_hScrollData( NULL ),
     d_vScrollData( NULL ),
-    d_inZoom( false ),
-    d_alignCanvasToScales( false )
+    d_inZoom( false )
 {
+    for ( int axis = 0; axis < QwtPlot::axisCnt; axis++ )
+        d_alignCanvasToScales[ axis ] = false;
+
     if ( !canvas )
         return;
 
@@ -61,7 +63,9 @@ void ScrollZoomer::rescale()
             yScale->setMinBorderDist( 0, 0 );
 
             QwtPlotLayout *layout = plot()->plotLayout();
-            layout->setAlignCanvasToScales( d_alignCanvasToScales );
+
+            for ( int axis = 0; axis < QwtPlot::axisCnt; axis++ )
+                layout->setAlignCanvasToScale( axis, d_alignCanvasToScales[ axis ] );
 
             d_inZoom = false;
         }
@@ -87,7 +91,12 @@ void ScrollZoomer::rescale()
             yScale->setMinBorderDist( start, end );
 
             QwtPlotLayout *layout = plot()->plotLayout();
-            d_alignCanvasToScales = layout->alignCanvasToScales();
+            for ( int axis = 0; axis < QwtPlot::axisCnt; axis++ )
+            {
+                d_alignCanvasToScales[axis] = 
+                    layout->alignCanvasToScale( axis );
+            }
+
             layout->setAlignCanvasToScales( false );
 
             d_inZoom = true;
@@ -209,19 +218,21 @@ bool ScrollZoomer::eventFilter( QObject *object, QEvent *event )
         {
             case QEvent::Resize:
             {
-                const int fw = canvas()->frameWidth();
+                int left, top, right, bottom;
+                canvas()->getContentsMargins( &left, &top, &right, &bottom );
 
                 QRect rect;
-                rect.setSize( ( ( QResizeEvent * )event )->size() );
-                rect.setRect( rect.x() + fw, rect.y() + fw,
-                    rect.width() - 2 * fw, rect.height() - 2 * fw );
+                rect.setSize( static_cast<QResizeEvent *>( event )->size() );
+                rect.adjust( left, top, -right, -bottom );
 
                 layoutScrollBars( rect );
                 break;
             }
             case QEvent::ChildRemoved:
             {
-                const QObject *child = ( ( QChildEvent * )event )->child();
+                const QObject *child =
+                    static_cast<QChildEvent *>( event )->child();
+
                 if ( child == d_cornerWidget )
                     d_cornerWidget = NULL;
                 else if ( child == d_hScrollData->scrollBar )
@@ -301,12 +312,8 @@ void ScrollZoomer::updateScrollBars()
     if ( showHScrollBar )
     {
         ScrollBar *sb = scrollBar( Qt::Horizontal );
-
         sb->setPalette( plot()->palette() );
-
-        const QwtScaleDiv *sd = plot()->axisScaleDiv( xAxis );
-        sb->setInverted( sd->lowerBound() > sd->upperBound() );
-
+        sb->setInverted( !plot()->axisScaleDiv( xAxis ).isIncreasing() );
         sb->setBase( zoomBase().left(), zoomBase().right() );
         sb->moveSlider( zoomRect().left(), zoomRect().right() );
 
@@ -331,12 +338,8 @@ void ScrollZoomer::updateScrollBars()
     if ( showVScrollBar )
     {
         ScrollBar *sb = scrollBar( Qt::Vertical );
-
         sb->setPalette( plot()->palette() );
-
-        const QwtScaleDiv *sd = plot()->axisScaleDiv( yAxis );
-        sb->setInverted( sd->lowerBound() < sd->upperBound() );
-
+        sb->setInverted( !plot()->axisScaleDiv( yAxis ).isIncreasing() );
         sb->setBase( zoomBase().top(), zoomBase().bottom() );
         sb->moveSlider( zoomRect().top(), zoomRect().bottom() );
 
