@@ -6,6 +6,10 @@
 #include <qwt_plot_layout.h>
 #include <qwt_scale_widget.h>
 #include <qwt_scale_draw.h>
+#ifndef QWT_NO_OPENGL
+#include <qevent.h>
+#include <qwt_plot_glcanvas.h>
+#endif
 #include "plot.h"
 #include "circularbuffer.h"
 #include "settings.h"
@@ -25,9 +29,35 @@ static double wave( double x )
 
 static double noise( double )
 {
-    return 2.0 * ( qrand() / ( ( double )RAND_MAX + 1 ) ) - 1.0;
+    return 2.0 * ( qrand() / ( static_cast<double>( RAND_MAX ) + 1 ) ) - 1.0;
 }
 
+#ifndef QWT_NO_OPENGL
+class GLCanvas: public QwtPlotGLCanvas
+{
+public:
+    GLCanvas( QwtPlot *parent = NULL ):
+        QwtPlotGLCanvas( parent )
+    {
+        setContentsMargins( 1, 1, 1, 1 );
+    }
+
+protected:
+    virtual void paintEvent( QPaintEvent *event )
+    {
+        QPainter painter( this );
+        painter.setClipRegion( event->region() );
+
+        QwtPlot *plot = qobject_cast< QwtPlot *>( parent() );
+        if ( plot )
+            plot->drawCanvas( &painter );
+
+        painter.setPen( palette().foreground().color() );
+        painter.drawRect( rect().adjusted( 0, 0, -1, -1 ) );
+    }
+};
+#endif
+
 Plot::Plot( QWidget *parent ):
     QwtPlot( parent ),
     d_interval( 10.0 ), // seconds
@@ -36,7 +66,12 @@ Plot::Plot( QWidget *parent ):
     // Assign a title
     setTitle( "Testing Refresh Rates" );
 
-    setCanvasBackground( Qt::white );
+    QwtPlotCanvas *canvas = new QwtPlotCanvas();
+    canvas->setFrameStyle( QFrame::Box | QFrame::Plain );
+    canvas->setLineWidth( 1 );
+    canvas->setPalette( Qt::white );
+
+    setCanvas( canvas );
 
     alignScales();
 
@@ -46,7 +81,7 @@ Plot::Plot( QWidget *parent ):
 
     // Insert curve
     d_curve = new QwtPlotCurve( "Data Moving Right" );
-    d_curve->setPen( QPen( Qt::black ) );
+    d_curve->setPen( Qt::black );
     d_curve->setData( new CircularBuffer( d_interval, 10 ) );
     d_curve->attach( this );
 
@@ -71,9 +106,6 @@ void Plot::alignScales()
     // the canvas frame, but is also a good example demonstrating
     // why the spreaded API needs polishing.
 
-    canvas()->setFrameStyle( QFrame::Box | QFrame::Plain );
-    canvas()->setLineWidth( 1 );
-
     for ( int i = 0; i < QwtPlot::axisCnt; i++ )
     {
         QwtScaleWidget *scaleWidget = axisWidget( i );
@@ -98,7 +130,7 @@ void Plot::setSettings( const Settings &s )
     d_grid->setPen( s.grid.pen );
     d_grid->setVisible( s.grid.pen.style() != Qt::NoPen );
 
-    CircularBuffer *buffer = ( CircularBuffer * )d_curve->data();
+    CircularBuffer *buffer = static_cast<CircularBuffer *>( d_curve->data() );
     if ( s.curve.numPoints != buffer->size() ||
             s.curve.functionType != d_settings.curve.functionType )
     {
@@ -122,15 +154,45 @@ void Plot::setSettings( const Settings &s )
 
     d_curve->setPaintAttribute( QwtPlotCurve::ClipPolygons,
         s.curve.paintAttributes & QwtPlotCurve::ClipPolygons );
-    d_curve->setRenderHint( QwtPlotCurve::RenderAntialiased,
-        s.curve.renderHint & QwtPlotCurve::RenderAntialiased );
+    d_curve->setPaintAttribute( QwtPlotCurve::FilterPoints,
+        s.curve.paintAttributes & QwtPlotCurve::FilterPoints );
 
-    canvas()->setAttribute( Qt::WA_PaintOnScreen, s.canvas.paintOnScreen );
+    d_curve->setRenderHint( QwtPlotItem::RenderAntialiased,
+        s.curve.renderHint & QwtPlotItem::RenderAntialiased );
 
-    canvas()->setPaintAttribute(
-        QwtPlotCanvas::BackingStore, s.canvas.useBackingStore );
-    canvas()->setPaintAttribute(
-        QwtPlotCanvas::ImmediatePaint, s.canvas.immediatePaint );
+#ifndef QWT_NO_OPENGL
+    if ( s.canvas.openGL )
+    {
+        QwtPlotGLCanvas *plotCanvas = qobject_cast<QwtPlotGLCanvas *>( canvas() );
+        if ( plotCanvas == NULL )
+        {
+            plotCanvas = new GLCanvas();
+            plotCanvas->setPalette( QColor( "khaki" ) );
+
+            setCanvas( plotCanvas );
+        }
+    }
+    else
+#endif
+    {
+        QwtPlotCanvas *plotCanvas = qobject_cast<QwtPlotCanvas *>( canvas() );
+        if ( plotCanvas == NULL )
+        {
+            plotCanvas = new QwtPlotCanvas();
+            plotCanvas->setFrameStyle( QFrame::Box | QFrame::Plain );
+            plotCanvas->setLineWidth( 1 );
+            plotCanvas->setPalette( Qt::white );
+
+            setCanvas( plotCanvas );
+        }
+
+        plotCanvas->setAttribute( Qt::WA_PaintOnScreen, s.canvas.paintOnScreen );
+
+        plotCanvas->setPaintAttribute(
+            QwtPlotCanvas::BackingStore, s.canvas.useBackingStore );
+        plotCanvas->setPaintAttribute(
+            QwtPlotCanvas::ImmediatePaint, s.canvas.immediatePaint );
+    }
 
     QwtPainter::setPolylineSplitting( s.curve.lineSplitting );
 
@@ -139,22 +201,18 @@ void Plot::setSettings( const Settings &s )
 
 void Plot::timerEvent( QTimerEvent * )
 {
-    CircularBuffer *buffer = ( CircularBuffer * )d_curve->data();
+    CircularBuffer *buffer = static_cast<CircularBuffer *>( d_curve->data() );
     buffer->setReferenceTime( d_clock.elapsed() / 1000.0 );
 
-    switch( d_settings.updateType )
+    if ( d_settings.updateType == Settings::RepaintCanvas )
     {
-        case Settings::RepaintCanvas:
-        {
-            // the axes in this example doesn't change. So all we need to do
-            // is to repaint the canvas.
+        // the axes in this example doesn't change. So all we need to do
+        // is to repaint the canvas.
 
-            canvas()->replot();
-            break;
-        }
-        default:
-        {
-            replot();
-        }
+        QMetaObject::invokeMethod( canvas(), "replot", Qt::DirectConnection );
+    }
+    else
+    {
+        replot();
     }
 }
