@@ -4,11 +4,12 @@
 #include <qwt_plot_marker.h>
 #include <qwt_plot_curve.h>
 #include <qwt_legend.h>
-#include <qwt_series_data.h>
+#include <qwt_point_data.h>
 #include <qwt_plot_canvas.h>
 #include <qwt_plot_panner.h>
 #include <qwt_plot_magnifier.h>
 #include <qwt_text.h>
+#include <qwt_symbol.h>
 #include <qwt_math.h>
 #include <math.h>
 
@@ -38,6 +39,36 @@ private:
     double( *d_y )( double );
 };
 
+class ArrowSymbol: public QwtSymbol
+{
+public:
+    ArrowSymbol()
+    {
+        QPen pen( Qt::black, 0 );
+        pen.setJoinStyle( Qt::MiterJoin );
+
+        setPen( pen );
+        setBrush( Qt::red );
+
+        QPainterPath path;
+        path.moveTo( 0, 8 );
+        path.lineTo( 0, 5 );
+        path.lineTo( -3, 5 );
+        path.lineTo( 0, 0 );
+        path.lineTo( 3, 5 );
+        path.lineTo( 0, 5 );
+
+        QTransform transform;
+        transform.rotate( -30.0 );
+        path = transform.map( path );
+
+        setPath( path );
+        setPinPoint( QPointF( 0, 0 ) );
+
+        setSize( 10, 14 );
+    }
+};
+
 class Plot : public QwtPlot
 {
 public:
@@ -55,12 +86,6 @@ private:
 Plot::Plot( QWidget *parent ):
     QwtPlot( parent )
 {
-    // panning with the left mouse button
-    ( void ) new QwtPlotPanner( canvas() );
-
-    // zoom in/out with the wheel
-    ( void ) new QwtPlotMagnifier( canvas() );
-
     setAutoFillBackground( true );
     setPalette( QPalette( QColor( 165, 193, 228 ) ) );
     updateGradient();
@@ -76,13 +101,22 @@ Plot::Plot( QWidget *parent ):
     setAxisScale( yLeft, -1.0, 1.0 );
 
     // canvas
-    canvas()->setLineWidth( 1 );
-    canvas()->setFrameStyle( QFrame::Box | QFrame::Plain );
-    canvas()->setBorderRadius( 15 );
+    QwtPlotCanvas *canvas = new QwtPlotCanvas();
+    canvas->setLineWidth( 1 );
+    canvas->setFrameStyle( QFrame::Box | QFrame::Plain );
+    canvas->setBorderRadius( 15 );
 
     QPalette canvasPalette( Qt::white );
     canvasPalette.setColor( QPalette::Foreground, QColor( 133, 190, 232 ) );
-    canvas()->setPalette( canvasPalette );
+    canvas->setPalette( canvasPalette );
+
+    setCanvas( canvas );
+
+    // panning with the left mouse button
+    ( void ) new QwtPlotPanner( canvas );
+
+    // zoom in/out with the wheel
+    ( void ) new QwtPlotMagnifier( canvas );
 
     populate();
 }
@@ -93,13 +127,13 @@ void Plot::populate()
     QwtPlotCurve *cSin = new QwtPlotCurve( "y = sin(x)" );
     cSin->setRenderHint( QwtPlotItem::RenderAntialiased );
     cSin->setLegendAttribute( QwtPlotCurve::LegendShowLine, true );
-    cSin->setPen( QPen( Qt::red ) );
+    cSin->setPen( Qt::red );
     cSin->attach( this );
 
     QwtPlotCurve *cCos = new QwtPlotCurve( "y = cos(x)" );
     cCos->setRenderHint( QwtPlotItem::RenderAntialiased );
     cCos->setLegendAttribute( QwtPlotCurve::LegendShowLine, true );
-    cCos->setPen( QPen( Qt::blue ) );
+    cCos->setPen( Qt::blue );
     cCos->attach( this );
 
     // Create sin and cos data
@@ -122,9 +156,21 @@ void Plot::populate()
     mX->setLabelAlignment( Qt::AlignLeft | Qt::AlignBottom );
     mX->setLabelOrientation( Qt::Vertical );
     mX->setLineStyle( QwtPlotMarker::VLine );
-    mX->setLinePen( QPen( Qt::black, 0, Qt::DashDotLine ) );
+    mX->setLinePen( Qt::black, 0, Qt::DashDotLine );
     mX->setXValue( 2.0 * M_PI );
     mX->attach( this );
+
+    const double x = 7.7;
+
+    // an arrow at a specific position
+    QwtPlotMarker *mPos = new QwtPlotMarker( "Marker" );
+    mPos->setRenderHint( QwtPlotItem::RenderAntialiased, true );
+    mPos->setItemAttribute( QwtPlotItem::Legend, true );
+    mPos->setSymbol( new ArrowSymbol() );
+    mPos->setValue( QPointF( x, ::sin( x ) ) );
+    mPos->setLabel( QString( "x = %1" ).arg( x ) );
+    mPos->setLabelAlignment( Qt::AlignRight | Qt::AlignBottom );
+    mPos->attach( this );
 }
 
 void Plot::updateGradient()
@@ -133,20 +179,10 @@ void Plot::updateGradient()
 
     const QColor buttonColor = pal.color( QPalette::Button );
 
-#ifdef Q_WS_X11
-    // Qt 4.7.1: QGradient::StretchToDeviceMode is buggy on X11
-
     QLinearGradient gradient( rect().topLeft(), rect().bottomLeft() );
     gradient.setColorAt( 0.0, Qt::white );
     gradient.setColorAt( 0.7, buttonColor );
     gradient.setColorAt( 1.0, buttonColor );
-#else
-    QLinearGradient gradient( 0, 0, 0, 1 );
-    gradient.setCoordinateMode( QGradient::StretchToDeviceMode );
-    gradient.setColorAt( 0.0, Qt::white );
-    gradient.setColorAt( 0.7, buttonColor );
-    gradient.setColorAt( 1.0, buttonColor );
-#endif
 
     pal.setBrush( QPalette::Window, gradient );
     setPalette( pal );
@@ -155,9 +191,9 @@ void Plot::updateGradient()
 void Plot::resizeEvent( QResizeEvent *event )
 {
     QwtPlot::resizeEvent( event );
-#ifdef Q_WS_X11
+
+    // Qt 4.7.1: QGradient::StretchToDeviceMode is buggy on X11
     updateGradient();
-#endif
 }
 
 int main( int argc, char **argv )
