@@ -6,11 +6,21 @@ class Plot: public QwtPlot
     Q_OBJECT
 
 public:
+    enum ColorMap
+    {
+        RGBMap,
+        IndexMap,
+        HueMap,
+        AlphaMap
+    };
+
     Plot( QWidget * = NULL );
 
 public Q_SLOTS:
     void showContour( bool on );
     void showSpectrogram( bool on );
+    void setColorMap( int );
+    void setAlpha( int );
 
 #ifndef QT_NO_PRINTER
     void printPlot();
@@ -18,4 +28,7 @@ public Q_SLOTS:
 
 private:
     QwtPlotSpectrogram *d_spectrogram;
+
+    int d_mapType;
+    int d_alpha;
 };
